@@ -194,7 +194,7 @@ def construct_config_error_msg(errors: Dict[str, Any]) -> str:
     return error_msg
 
 
-def purge_invalid_wayland_rules(config: Dict) -> None:
+def unset_invalid_x11_options(config: Dict) -> None:
     if config["rules"] is not None:
         rules = list()
         for rule in config["rules"]:
@@ -209,6 +209,24 @@ def purge_invalid_wayland_rules(config: Dict) -> None:
         config["rules"] = rules
 
 
+def unset_invalid_sway_options(config: Dict) -> None:
+    if config["flash_fullscreen"] is True:
+        logging.warning(
+            "Fullscreen windows cannot be flashed in sway. Setting flash-fullscreen=false. "
+            "https://github.com/fennerm/flashfocus/issues/55"
+        )
+        config["flash_fullscreen"] = False
+
+
+def unset_invalid_options_for_wm(config: Dict) -> None:
+    """Clear any config options which don't work with the user's WM."""
+    display_protocol = get_display_protocol()
+    if display_protocol == DisplayProtocol.X11:
+        unset_invalid_x11_options(config)
+    elif display_protocol == DisplayProtocol.SWAY:
+        unset_invalid_sway_options(config)
+
+
 def validate_config(config: Dict) -> Dict:
     """Validate the config file and command line parameters."""
     try:
@@ -224,14 +242,14 @@ def validate_config(config: Dict) -> Dict:
 
     try:
         # In marshmallow v2 the validated data needed to be accessed from the tuple after load
-        validated = loaded.data
+        validated_config = loaded.data
     except AttributeError:
         # In marshmallow v3 the validated data is returned directly from load
-        validated = loaded
+        validated_config = loaded
 
-    if get_display_protocol() == DisplayProtocol.X11:
-        purge_invalid_wayland_rules(validated)
-    return validated
+    unset_invalid_options_for_wm(validated_config)
+
+    return validated_config
 
 
 def dehyphen(config: Dict) -> None:
